semconv

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 13, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package semconv defines OpenTelemetry semantic convention attribute keys used by gofuncy for metrics and traces.

Index

Constants

const (
	// RoutineNameKey is the attribute key for the goroutine name.
	RoutineNameKey = attribute.Key("gofuncy.routine.name")
	// RoutineParentKey is the attribute key for the parent goroutine name.
	RoutineParentKey = attribute.Key("gofuncy.routine.parent")
	// ChanNameKey is the attribute key for the channel name.
	ChanNameKey = attribute.Key("gofuncy.chan.name")
	// ChanCapKey is the attribute key for the channel buffer capacity.
	ChanCapKey = attribute.Key("gofuncy.chan.cap")
	// ChanSizeKey is the attribute key for the current channel buffer length.
	ChanSizeKey = attribute.Key("gofuncy.chan.size")
	// GroupSizeKey is the attribute key for the number of functions in a group.
	GroupSizeKey = attribute.Key("gofuncy.group.size")
	// ErrorKey is the attribute key indicating whether an error occurred.
	ErrorKey = attribute.Key("error")
)

Attribute keys for gofuncy telemetry.

Variables

This section is empty.

Functions

func ChanCap

func ChanCap(v int) attribute.KeyValue

ChanCap returns an attribute with the channel buffer capacity.

func ChanName

func ChanName(v string) attribute.KeyValue

ChanName returns an attribute with the channel name.

func ChanSize

func ChanSize(v int) attribute.KeyValue

ChanSize returns an attribute with the current channel buffer length.

func Error

func Error(v bool) attribute.KeyValue

Error returns an attribute indicating whether an error occurred.

func GroupSize

func GroupSize(v int) attribute.KeyValue

GroupSize returns an attribute with the number of functions in a group.

func RoutineName

func RoutineName(v string) attribute.KeyValue

RoutineName returns an attribute with the goroutine name.

func RoutineParent

func RoutineParent(v string) attribute.KeyValue

RoutineParent returns an attribute with the parent goroutine name.

Types

This section is empty.

Directories

Path Synopsis
Package gofuncyconv provides typed OpenTelemetry metric instrument wrappers for gofuncy's goroutine, group, channel, and message metrics.
Package gofuncyconv provides typed OpenTelemetry metric instrument wrappers for gofuncy's goroutine, group, channel, and message metrics.

Jump to