Documentation
¶
Overview ¶
Package semconv defines OpenTelemetry semantic convention attribute keys used by gofuncy for metrics and traces.
Index ¶
- Constants
- func ChanCap(v int) attribute.KeyValue
- func ChanName(v string) attribute.KeyValue
- func ChanSize(v int) attribute.KeyValue
- func Error(v bool) attribute.KeyValue
- func GroupSize(v int) attribute.KeyValue
- func RoutineName(v string) attribute.KeyValue
- func RoutineParent(v string) attribute.KeyValue
Constants ¶
const ( // RoutineNameKey is the attribute key for the goroutine name. RoutineNameKey = attribute.Key("gofuncy.routine.name") // RoutineParentKey is the attribute key for the parent goroutine name. RoutineParentKey = attribute.Key("gofuncy.routine.parent") // ChanNameKey is the attribute key for the channel name. ChanNameKey = attribute.Key("gofuncy.chan.name") // ChanCapKey is the attribute key for the channel buffer capacity. ChanCapKey = attribute.Key("gofuncy.chan.cap") // ChanSizeKey is the attribute key for the current channel buffer length. ChanSizeKey = attribute.Key("gofuncy.chan.size") // GroupSizeKey is the attribute key for the number of functions in a group. GroupSizeKey = attribute.Key("gofuncy.group.size") // ErrorKey is the attribute key indicating whether an error occurred. ErrorKey = attribute.Key("error") )
Attribute keys for gofuncy telemetry.
Variables ¶
This section is empty.
Functions ¶
func RoutineName ¶
RoutineName returns an attribute with the goroutine name.
func RoutineParent ¶
RoutineParent returns an attribute with the parent goroutine name.
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package gofuncyconv provides typed OpenTelemetry metric instrument wrappers for gofuncy's goroutine, group, channel, and message metrics.
|
Package gofuncyconv provides typed OpenTelemetry metric instrument wrappers for gofuncy's goroutine, group, channel, and message metrics. |
Click to show internal directories.
Click to hide internal directories.